import { forwardRef, Module } from '@nestjs/common';
import { JwtModule } from '@nestjs/jwt';
import { TypeOrmModule } from '@nestjs/typeorm';
import { CustomerModule } from '~/customer/customer.module';
import { AuthController } from './controllers';
import { Device, User, UserNotificationSettings } from './entities';
import { DeviceRepository, UserRepository } from './repositories';
import { AuthService, DeviceService } from './services';
import { UserService } from './services/user.service';
import { AccessTokenStrategy } from './strategies';

@Module({
  imports: [
    TypeOrmModule.forFeature([User, UserNotificationSettings, Device]),
    JwtModule.register({}),
    forwardRef(() => CustomerModule),
  ],
  providers: [AuthService, UserRepository, UserService, DeviceService, DeviceRepository, AccessTokenStrategy],
  controllers: [AuthController],
  exports: [UserService],
})
export class AuthModule {}
