import { ApiProperty } from '@nestjs/swagger';
import { Matches } from 'class-validator';
import { i18nValidationMessage as i18n } from 'nestjs-i18n';
import { COUNTRY_CODE_REGEX } from '~/auth/constants';
import { IsValidPhoneNumber } from '~/core/decorators/validations';

export class CreateUnverifiedUserRequestDto {
  @ApiProperty({ example: '+962' })
  @Matches(COUNTRY_CODE_REGEX, {
    message: i18n('validation.Matches', { path: 'general', property: 'auth.countryCode' }),
  })
  countryCode: string = '+966';

  @ApiProperty({ example: '787259134' })
  @IsValidPhoneNumber({
    message: i18n('validation.IsValidPhoneNumber', { path: 'general', property: 'auth.phoneNumber' }),
  })
  phoneNumber!: string;
}
