import { ApiProperty } from '@nestjs/swagger';
import { IsEmail, IsNotEmpty, IsNumberString, IsString, MaxLength, MinLength } from 'class-validator';
import { i18nValidationMessage as i18n } from 'nestjs-i18n';
import { DEFAULT_OTP_LENGTH } from '~/common/modules/otp/constants';
export class ForgetPasswordRequestDto {
  @ApiProperty({ example: 'test@test.com' })
  @IsEmail({}, { message: i18n('validation.IsEmail', { path: 'general', property: 'auth.email' }) })
  email!: string;

  @ApiProperty({ example: 'password' })
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'auth.password' }) })
  @IsNotEmpty({ message: i18n('validation.IsNotEmpty', { path: 'general', property: 'auth.password' }) })
  password!: string;

  @ApiProperty({ example: 'password' })
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'auth.confirmPassword' }) })
  @IsNotEmpty({ message: i18n('validation.IsNotEmpty', { path: 'general', property: 'auth.confirmPassword' }) })
  confirmPassword!: string;

  @ApiProperty({ example: '111111' })
  @IsNumberString(
    { no_symbols: true },
    { message: i18n('validation.IsNumberString', { path: 'general', property: 'auth.otp' }) },
  )
  @MaxLength(DEFAULT_OTP_LENGTH, {
    message: i18n('validation.MaxLength', { path: 'general', property: 'auth.otp', length: DEFAULT_OTP_LENGTH }),
  })
  @MinLength(DEFAULT_OTP_LENGTH, {
    message: i18n('validation.MinLength', { path: 'general', property: 'auth.otp', length: DEFAULT_OTP_LENGTH }),
  })
  otp!: string;
}
