import { ApiProperty } from '@nestjs/swagger';
import { IsEmail, IsEnum, IsString, ValidateIf } from 'class-validator';
import { i18nValidationMessage as i18n } from 'nestjs-i18n';
import { GrantType } from '~/auth/enums';
export class LoginRequestDto {
  @ApiProperty({ example: GrantType.PASSWORD })
  @IsEnum(GrantType, { message: i18n('validation.IsEnum', { path: 'general', property: 'auth.grantType' }) })
  grantType!: GrantType;

  @ApiProperty({ example: 'test@test.com' })
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'auth.email' }) })
  @IsEmail({}, { message: i18n('validation.IsEmail', { path: 'general', property: 'auth.email' }) })
  email!: string;

  @ApiProperty({ example: '123456' })
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'auth.password' }) })
  @ValidateIf((o) => o.grantType === GrantType.PASSWORD)
  password!: string;

  @ApiProperty({ example: 'device-token' })
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'auth.deviceToken' }) })
  @ValidateIf((o) => o.grantType === GrantType.BIOMETRIC)
  deviceToken!: string;
}
