import {
  BaseEntity,
  Column,
  CreateDateColumn,
  Entity,
  JoinColumn,
  OneToMany,
  OneToOne,
  PrimaryGeneratedColumn,
  UpdateDateColumn,
} from 'typeorm';
import { Otp } from '~/common/modules/otp/entities';
import { Customer } from '~/customer/entities/customer.entity';
import { Document } from '~/document/entities';
import { Roles } from '../enums';
import { Device } from './device.entity';
import { UserNotificationSettings } from './user-notification-settings.entity';

@Entity('users')
export class User extends BaseEntity {
  @PrimaryGeneratedColumn('uuid')
  id!: string;

  @Column('varchar', { length: 255, nullable: true, name: 'email' })
  email!: string;

  @Column('varchar', { length: 255, name: 'phone_number' })
  phoneNumber!: string;

  @Column('varchar', { length: 10, name: 'country_code' })
  countryCode!: string;

  @Column('varchar', { length: 255, name: 'password', nullable: true })
  password!: string;

  @Column('varchar', { length: 255, name: 'salt', nullable: true })
  salt!: string;

  @Column('varchar', { length: 255, nullable: true, name: 'google_id' })
  googleId!: string;

  @Column('varchar', { length: 255, nullable: true, name: 'apple_id' })
  appleId!: string;

  @Column('boolean', { default: false, name: 'is_profile_completed' })
  isProfileCompleted!: boolean;

  @Column('text', { nullable: true, array: true, name: 'roles' })
  roles!: Roles[];

  @Column('varchar', { name: 'profile_picture_id', nullable: true })
  profilePictureId!: string;

  @OneToOne(() => Document, (document) => document.user, { cascade: true, nullable: true })
  @JoinColumn({ name: 'profile_picture_id' })
  profilePicture!: Document;

  @OneToMany(() => Otp, (otp) => otp.user)
  otp!: Otp[];

  @OneToOne(() => UserNotificationSettings, (notificationSettings) => notificationSettings.user, {
    cascade: true,
    eager: true,
  })
  notificationSettings!: UserNotificationSettings;

  @OneToOne(() => Customer, (customer) => customer.user, { cascade: true, eager: true })
  customer!: Customer;

  @OneToMany(() => Device, (device) => device.user)
  devices!: Device[];

  @CreateDateColumn({ name: 'created_at', type: 'timestamp with time zone' })
  createdAt!: Date;

  @UpdateDateColumn({ name: 'updated_at', type: 'timestamp with time zone' })
  updatedAt!: Date;

  get isPasswordSet(): boolean {
    return !!this.password;
  }
}
