import { Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { FindOptionsWhere, Repository } from 'typeorm';
import { UpdateNotificationsSettingsRequestDto } from '~/customer/dtos/request';
import { User, UserNotificationSettings } from '../entities';

@Injectable()
export class UserRepository {
  constructor(@InjectRepository(User) private readonly userRepository: Repository<User>) {}

  createUnverifiedUser(data: Partial<User>) {
    return this.userRepository.save(
      this.userRepository.create({
        phoneNumber: data.phoneNumber,
        countryCode: data.countryCode,
        roles: data.roles,
        notificationSettings: UserNotificationSettings.create(),
      }),
    );
  }

  findOne(where: FindOptionsWhere<User> | FindOptionsWhere<User>[]) {
    return this.userRepository.findOne({ where });
  }

  updateNotificationSettings(user: User, body: UpdateNotificationsSettingsRequestDto) {
    user.notificationSettings = UserNotificationSettings.create({ ...user.notificationSettings, ...body });
    return this.userRepository.save(user);
  }

  update(userId: string, data: Partial<User>) {
    return this.userRepository.update(userId, data);
  }

  createUser(data: Partial<User>) {
    const user = this.userRepository.create({
      ...data,
      notificationSettings: UserNotificationSettings.create(),
    });

    return this.userRepository.save(user);
  }
}
