import { Column, CreateDateColumn, Entity, Index, JoinColumn, ManyToOne, PrimaryGeneratedColumn } from 'typeorm';
import { User } from '~/auth/entities';
import { OtpScope, OtpType } from '../enums';

@Entity('otp')
export class Otp {
  @PrimaryGeneratedColumn('uuid')
  id!: string;

  @Column('varchar', { length: 255, name: 'value' })
  value!: string;

  @Index()
  @Column('varchar', { length: 255, name: 'scope' })
  scope!: OtpScope;

  @Column('varchar', { length: 255, name: 'otp_type' })
  otpType!: OtpType;

  @Column('timestamp with time zone', { name: 'expires_at' })
  expiresAt!: Date;

  @Index()
  @Column('varchar', { name: 'user_id' })
  userId!: string;

  @ManyToOne(() => User, (user) => user.otp, { onDelete: 'CASCADE' })
  @JoinColumn({ name: 'user_id' })
  user!: User;

  @CreateDateColumn({ name: 'created_at', type: 'timestamp with time zone' })
  createdAt!: Date;
}
