import { Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { MoreThan, Repository } from 'typeorm';
import { Otp } from '../entities';
import { IVerifyOtp } from '../interfaces';
const FIVE = 5;
const SIXTY = 60;
const ONE_THOUSAND = 1000;
const FIVE_MINUTES_IN_MILLISECONDS = FIVE * SIXTY * ONE_THOUSAND;
@Injectable()
export class OtpRepository {
  constructor(@InjectRepository(Otp) private readonly otpRepository: Repository<Otp>) {}

  createOtp(otp: Partial<Otp>) {
    return this.otpRepository.save(
      this.otpRepository.create({
        userId: otp.userId,
        value: otp.value,
        scope: otp.scope,
        otpType: otp.otpType,
        expiresAt: new Date(Date.now() + FIVE_MINUTES_IN_MILLISECONDS),
      }),
    );
  }

  findOtp(otp: IVerifyOtp) {
    return this.otpRepository.findOne({
      where: {
        userId: otp.userId,
        scope: otp.scope,
        value: otp.value,
        otpType: otp.otpType,
        expiresAt: MoreThan(new Date()),
      },
      order: {
        createdAt: 'DESC',
      },
    });
  }
}
