import { Injectable } from '@nestjs/common';
import { ConfigService } from '@nestjs/config';
import { DEFAULT_OTP_DIGIT, DEFAULT_OTP_LENGTH } from '../constants';
import { OtpType } from '../enums';
import { ISendOtp, IVerifyOtp } from '../interfaces';
import { OtpRepository } from '../repositories';
import { generateRandomOtp } from '../utils';

@Injectable()
export class OtpService {
  constructor(private readonly configService: ConfigService, private readonly otpRepository: OtpRepository) {}
  private useMock = this.configService.get<boolean>('USE_MOCK', false);
  async generateAndSendOtp(sendotpRequest: ISendOtp): Promise<string> {
    const otp = this.useMock ? DEFAULT_OTP_DIGIT.repeat(DEFAULT_OTP_LENGTH) : generateRandomOtp(DEFAULT_OTP_LENGTH);

    await this.otpRepository.createOtp({ ...sendotpRequest, value: otp });

    this.sendOtp(sendotpRequest, otp);

    return sendotpRequest.otpType == OtpType.EMAIL
      ? sendotpRequest.recipient
      : sendotpRequest.recipient?.replace(/.(?=.{4})/g, '*');
  }

  async verifyOtp(verifyOtpRequest: IVerifyOtp) {
    const otp = await this.otpRepository.findOtp(verifyOtpRequest);

    return !!otp;
  }

  private sendOtp(sendotpRequest: ISendOtp, otp: string) {
    // TODO: send OTP to the user
    return;
  }
}
