import {
  registerDecorator,
  ValidationArguments,
  ValidationOptions,
  ValidatorConstraint,
  ValidatorConstraintInterface,
} from 'class-validator';
import moment from 'moment';
const EIGHTTEEN = 18;
export function IsAbove18(validationOptions?: ValidationOptions) {
  return (object: any, propertyName: string) => {
    registerDecorator({
      name: 'IsAbove18',
      target: object.constructor,
      propertyName,
      options: {
        message: `${propertyName} must be above 18 years old`,
        ...validationOptions,
      },
      constraints: [],
      validator: IsAbove18Constraint,
    });
  };
}

@ValidatorConstraint({ name: 'IsAbove18' })
export class IsAbove18Constraint implements ValidatorConstraintInterface {
  validate(value: any, args: ValidationArguments) {
    if (!value) return true;

    const dateOfBirth = moment(value);

    if (!dateOfBirth.isValid()) {
      return false;
    }

    const today = moment();
    const age = today.diff(dateOfBirth, 'years');

    return age >= EIGHTTEEN;
  }
}
