import {
  registerDecorator,
  ValidationArguments,
  ValidationOptions,
  ValidatorConstraint,
  ValidatorConstraintInterface,
} from 'class-validator';
import * as libphonenumber from 'google-libphonenumber';

const phoneUtil = libphonenumber.PhoneNumberUtil.getInstance();

export function IsValidPhoneNumber(validationOptions?: ValidationOptions) {
  return (object: any, propertyName: string) => {
    registerDecorator({
      name: 'IsValidPhoneNumber',
      target: object.constructor,
      propertyName,
      options: {
        message: `${propertyName} must be valid mobile number`,
        ...validationOptions,
      },
      constraints: [],
      validator: IsValidPhoneNumberConstraint,
    });
  };
}

@ValidatorConstraint({ name: 'IsValidPhoneNumber' })
export class IsValidPhoneNumberConstraint implements ValidatorConstraintInterface {
  validate(value: any, args: ValidationArguments) {
    const countryCode = (args.object as any).countryCode; // +962;
    const isoCountryCode = phoneUtil.getRegionCodeForCountryCode(+countryCode); // JO
    try {
      const parsedNumber = phoneUtil.parse(value, isoCountryCode);
      return phoneUtil.isValidNumberForRegion(parsedNumber, isoCountryCode);
    } catch (e) {
      return false;
    }
  }
}
