import { buildI18nOptions } from './i18n-options';
import { AcceptLanguageResolver, I18nJsonLoader, QueryResolver, I18nOptions } from 'nestjs-i18n';
import * as path from 'path';

describe('buildI18nOptions', () => {
  const baseI18nDir = path.join(__dirname, '..', '..', 'i18n');

  it('should return correct I18nOptions configuration', () => {
    const i18nOptions: I18nOptions = buildI18nOptions();

    // Assert fallbackLanguage
    expect(i18nOptions.fallbackLanguage).toBe('en');

    // Assert loader and loader options
    expect(i18nOptions.loader).toBe(I18nJsonLoader);
    expect(i18nOptions.loaderOptions).toEqual({
      path: baseI18nDir,
    });

    // Assert resolvers
    expect(i18nOptions.resolvers).toHaveLength(2);
    expect(i18nOptions.resolvers?.[0]).toBeInstanceOf(AcceptLanguageResolver);
    expect(i18nOptions.resolvers?.[1]).toBeInstanceOf(QueryResolver);
    // Additional checks for resolver configuration
    const queryResolver = i18nOptions.resolvers?.[1] as QueryResolver;
    expect(queryResolver['keys']).toEqual(['lang']); // Verify that 'lang' is the query parameter
  });
});
