import { createMock } from '@golevelup/ts-jest';
import { buildLoggerOptions } from './logger-options';
import { ConfigService } from '@nestjs/config';
import { Params } from 'nestjs-pino';

describe('buildLoggerOptions', () => {
  let configService: jest.Mocked<ConfigService>;

  beforeEach(() => {
    configService = createMock<ConfigService>();
  });

  it('should return correct logger options with default log level "info"', () => {
    configService.get.mockReturnValue('info');

    const loggerOptions: Params = buildLoggerOptions(configService);

    expect(loggerOptions).toEqual({
      pinoHttp: {
        level: 'info',
        transport: {
          target: 'pino-pretty',
          options: {
            singleLine: true,
          },
        },
      },
    });
  });

  it('should return correct logger options with custom log level', () => {
    configService.get.mockReturnValue('debug');

    const loggerOptions: Params = buildLoggerOptions(configService);

    expect(loggerOptions).toEqual({
      pinoHttp: {
        level: 'debug',
        transport: {
          target: 'pino-pretty',
          options: {
            singleLine: true,
          },
        },
      },
    });
  });
});
