import { Body, Controller, Patch, UseGuards } from '@nestjs/common';
import { ApiBearerAuth, ApiTags } from '@nestjs/swagger';
import { Roles } from '~/auth/enums';
import { IJwtPayload } from '~/auth/interfaces';
import { AllowedRoles, AuthenticatedUser } from '~/common/decorators';
import { AccessTokenGuard, RolesGuard } from '~/common/guards';
import { ResponseFactory } from '~/core/utils';
import { UpdateCustomerRequestDto, UpdateNotificationsSettingsRequestDto } from '../dtos/request';
import { CustomerResponseDto, NotificationSettingsResponseDto } from '../dtos/response';
import { CustomerService } from '../services';

@Controller('customers')
@ApiTags('Customers')
@ApiBearerAuth()
export class CustomerController {
  constructor(private readonly customerService: CustomerService) {}

  @Patch('')
  @UseGuards(RolesGuard)
  @AllowedRoles(Roles.GUARDIAN)
  async updateCustomer(@AuthenticatedUser() { sub }: IJwtPayload, @Body() body: UpdateCustomerRequestDto) {
    const customer = await this.customerService.updateCustomer(sub, body);

    return ResponseFactory.data(new CustomerResponseDto(customer));
  }

  @Patch('settings/notifications')
  @UseGuards(AccessTokenGuard)
  async updateNotificationSettings(
    @AuthenticatedUser() { sub }: IJwtPayload,
    @Body() body: UpdateNotificationsSettingsRequestDto,
  ) {
    const notificationSettings = await this.customerService.updateNotificationSettings(sub, body);

    return ResponseFactory.data(new NotificationSettingsResponseDto(notificationSettings));
  }
}
