import { ApiProperty } from '@nestjs/swagger';
import { IsDateString, IsNotEmpty, IsOptional, IsString } from 'class-validator';
import { i18nValidationMessage as i18n } from 'nestjs-i18n';
import { IsAbove18 } from '~/core/decorators/validations';
export class UpdateCustomerRequestDto {
  @ApiProperty({ example: 'John' })
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'customer.firstName' }) })
  @IsNotEmpty({ message: i18n('validation.IsNotEmpty', { path: 'general', property: 'customer.firstName' }) })
  @IsOptional()
  firstName!: string;

  @ApiProperty({ example: 'Doe' })
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'customer.lastName' }) })
  @IsNotEmpty({ message: i18n('validation.IsNotEmpty', { path: 'general', property: 'customer.lastName' }) })
  @IsOptional()
  lastName!: string;

  @ApiProperty({ example: 'JO' })
  @IsString({ message: i18n('validation.IsString', { path: 'general', property: 'customer.countryOfResidence' }) })
  @IsNotEmpty({ message: i18n('validation.IsNotEmpty', { path: 'general', property: 'customer.countryOfResidence' }) })
  @IsOptional()
  countryOfResidence!: string;

  @ApiProperty({ example: '2021-01-01' })
  @IsDateString({}, { message: i18n('validation.IsDateString', { path: 'general', property: 'customer.dateOfBirth' }) })
  @IsAbove18({ message: i18n('validation.IsAbove18', { path: 'general', property: 'customer.dateOfBirth' }) })
  @IsOptional()
  dateOfBirth!: Date;
}
