import {
  BaseEntity,
  Column,
  CreateDateColumn,
  Entity,
  JoinColumn,
  OneToOne,
  PrimaryColumn,
  UpdateDateColumn,
} from 'typeorm';
import { User } from '~/auth/entities';
import { Guardian } from '~/guardian/entities/guradian.entity';
import { Junior } from '~/junior/entities';

@Entity()
export class Customer extends BaseEntity {
  @PrimaryColumn('uuid')
  id!: string;

  @Column('varchar', { length: 255, default: 'PENDING', name: 'customer_status' })
  customerStatus!: string;

  @Column('text', { nullable: true, name: 'rejection_reason' })
  rejectionReason!: string;

  @Column('varchar', { length: 255, nullable: true, name: 'first_name' })
  firstName!: string;

  @Column('varchar', { length: 255, nullable: true, name: 'last_name' })
  lastName!: string;

  @Column('date', { nullable: true, name: 'date_of_birth' })
  dateOfBirth!: Date;

  @Column('varchar', { length: 255, nullable: true, name: 'national_id' })
  nationalId!: string;

  @Column('date', { nullable: true, name: 'national_id_expiry' })
  nationaIdExpiry!: Date;

  @Column('varchar', { length: 255, nullable: true, name: 'country_of_residence' })
  countryOfResidence!: string;

  @Column('varchar', { length: 255, nullable: true, name: 'source_of_income' })
  sourceOfIncome!: string;

  @Column('varchar', { length: 255, nullable: true, name: 'profession' })
  profession!: string;

  @Column('varchar', { length: 255, nullable: true, name: 'profession_type' })
  professionType!: string;

  @Column('boolean', { default: false, name: 'is_pep' })
  isPep!: boolean;

  @Column('varchar', { length: 255, nullable: true, name: 'gender' })
  gender!: string;

  @Column('boolean', { default: false, name: 'is_junior' })
  isJunior!: boolean;

  @Column('boolean', { default: false, name: 'is_guardian' })
  isGuardian!: boolean;

  @Column('varchar', { name: 'user_id' })
  userId!: string;

  @OneToOne(() => User, (user) => user.customer, { onDelete: 'CASCADE' })
  @JoinColumn({ name: 'user_id' })
  user!: User;

  @OneToOne(() => Junior, (junior) => junior.customer, { cascade: true })
  junior!: Junior;

  @OneToOne(() => Guardian, (guardian) => guardian.customer, { cascade: true })
  guardian!: Guardian;

  @CreateDateColumn({ type: 'timestamp with time zone', default: () => 'CURRENT_TIMESTAMP' })
  createdAt!: Date;

  @UpdateDateColumn({ type: 'timestamp with time zone', default: () => 'CURRENT_TIMESTAMP' })
  updatedAt!: Date;
}
