import { Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { FindOptionsWhere, Repository } from 'typeorm';
import { User } from '~/auth/entities';
import { Roles } from '~/auth/enums';
import { UpdateCustomerRequestDto } from '../dtos/request';
import { Customer } from '../entities';

@Injectable()
export class CustomerRepository {
  constructor(@InjectRepository(Customer) private readonly customerRepository: Repository<Customer>) {}

  updateCustomer(id: string, data: UpdateCustomerRequestDto) {
    return this.customerRepository.update(id, data);
  }

  findOne(where: FindOptionsWhere<Customer>) {
    return this.customerRepository.findOne({ where });
  }

  createCustomer(customerData: Partial<Customer>, user: User) {
    return this.customerRepository.save(
      this.customerRepository.create({
        ...customerData,
        id: user.id,
        user,
        isGuardian: user.roles.includes(Roles.GUARDIAN),
        isJunior: user.roles.includes(Roles.JUNIOR),
      }),
    );
  }
}
