import { BadRequestException, forwardRef, Inject, Injectable } from '@nestjs/common';
import { User } from '~/auth/entities';
import { UserService } from '~/auth/services/user.service';
import { UpdateCustomerRequestDto, UpdateNotificationsSettingsRequestDto } from '../dtos/request';
import { Customer } from '../entities';
import { CustomerRepository } from '../repositories/customer.repository';

@Injectable()
export class CustomerService {
  constructor(
    @Inject(forwardRef(() => UserService)) private readonly userService: UserService,
    private readonly customerRepository: CustomerRepository,
  ) {}
  updateNotificationSettings(userId: string, data: UpdateNotificationsSettingsRequestDto) {
    return this.userService.updateNotificationSettings(userId, data);
  }

  async updateCustomer(userId: string, data: UpdateCustomerRequestDto): Promise<Customer> {
    await this.customerRepository.updateCustomer(userId, data);
    return this.findCustomerById(userId);
  }

  createCustomer(customerData: Partial<Customer>, user: User) {
    return this.customerRepository.createCustomer(customerData, user);
  }

  async findCustomerById(id: string) {
    const customer = await this.customerRepository.findOne({ id });
    if (!customer) {
      throw new BadRequestException('CUSTOMER.NOT_FOUND');
    }
    return customer;
  }
}
