import {
  BaseEntity,
  Column,
  CreateDateColumn,
  Entity,
  JoinColumn,
  ManyToOne,
  OneToMany,
  OneToOne,
  PrimaryColumn,
  UpdateDateColumn,
} from 'typeorm';
import { Customer } from '~/customer/entities';
import { Document } from '~/document/entities';
import { Guardian } from '~/guardian/entities/guradian.entity';
import { Task } from '~/task/entities';
import { Relationship } from '../enums';
import { Theme } from './theme.entity';

@Entity('juniors')
export class Junior extends BaseEntity {
  @PrimaryColumn('uuid')
  id!: string;

  @Column('varchar', { length: 255 })
  relationship!: Relationship;

  @Column('uuid', { name: 'civil_id_front_id' })
  civilIdFrontId!: string;

  @Column('uuid', { name: 'civil_id_back_id' })
  civilIdBackId!: string;

  @Column('uuid', { name: 'customer_id' })
  customerId!: string;

  @Column('uuid', { name: 'guardian_id' })
  guardianId!: string;

  @OneToOne(() => Document, (document) => document.juniorCivilIdFront)
  @JoinColumn({ name: 'civil_id_front_id' })
  civilIdFront!: Document;

  @OneToOne(() => Document, (document) => document.juniorCivilIdBack)
  @JoinColumn({ name: 'civil_id_back_id' })
  civilIdBack!: Document;

  @OneToOne(() => Customer, (customer) => customer.junior, { onDelete: 'CASCADE' })
  @JoinColumn({ name: 'customer_id' })
  customer!: Customer;

  @OneToOne(() => Theme, (theme) => theme.junior, { cascade: true, nullable: true })
  theme!: Theme;

  @ManyToOne(() => Guardian, (guardian) => guardian.juniors)
  @JoinColumn({ name: 'guardian_id' })
  guardian!: Guardian;

  @OneToMany(() => Task, (task) => task.assignedTo)
  tasks?: Task[];

  @CreateDateColumn({ name: 'created_at', type: 'timestamp', default: () => 'CURRENT_TIMESTAMP' })
  createdAt!: Date;

  @UpdateDateColumn({ name: 'updated_at', type: 'timestamp', default: () => 'CURRENT_TIMESTAMP' })
  updatedAt!: Date;
}
