import {
  BaseEntity,
  Column,
  CreateDateColumn,
  Entity,
  JoinColumn,
  ManyToOne,
  OneToOne,
  PrimaryGeneratedColumn,
  UpdateDateColumn,
} from 'typeorm';
import { Document } from '~/document/entities';
import { SubmissionStatus } from '../enums';
import { Task } from './task.entity';

@Entity('task_submissions')
export class TaskSubmission extends BaseEntity {
  @PrimaryGeneratedColumn('uuid')
  id!: string;

  @Column({ type: 'varchar', name: 'status' })
  status!: SubmissionStatus;

  @Column({ type: 'timestamp with time zone', name: 'submitted_at' })
  submittedAt!: Date;

  @Column({ type: 'uuid', name: 'task_id' })
  taskId!: string;

  @Column({ type: 'uuid', name: 'proof_of_completion_id', nullable: true })
  proofOfCompletionId!: string;

  @OneToOne(() => Task, (task) => task.submission, { onDelete: 'CASCADE' })
  @JoinColumn({ name: 'task_id' })
  task!: Task;

  @ManyToOne(() => Document, (document) => document.submissions, { nullable: true })
  @JoinColumn({ name: 'proof_of_completion_id' })
  proofOfCompletion!: Document;

  @CreateDateColumn({ type: 'timestamp', name: 'created_at', default: () => 'CURRENT_TIMESTAMP' })
  createdAt!: Date;

  @UpdateDateColumn({ type: 'timestamp', name: 'updated_at', default: () => 'CURRENT_TIMESTAMP' })
  updatedAt!: Date;
}
